==> ec2-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnVPNGatewayRoutePropagationProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::VPNGatewayRoutePropagation`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:16:48.819Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnVPNGatewayRoutePropagationProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::EC2::VPNGatewayRoutePropagation.RouteTableIds`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html#cfn-ec2-vpngatewayrouteprop-routetableids
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<java.lang.String> getRouteTableIds();

    /**
     * `AWS::EC2::VPNGatewayRoutePropagation.VpnGatewayId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html#cfn-ec2-vpngatewayrouteprop-vpngatewayid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getVpnGatewayId();

    /**
     * @return a {@link Builder} of {@link CfnVPNGatewayRoutePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnVPNGatewayRoutePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        private java.util.List<java.lang.String> routeTableIds;
        private java.lang.String vpnGatewayId;

        /**
         * Sets the value of RouteTableIds
         * @param routeTableIds `AWS::EC2::VPNGatewayRoutePropagation.RouteTableIds`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder routeTableIds(java.util.List<java.lang.String> routeTableIds) {
            this.routeTableIds = routeTableIds;
            return this;
        }

        /**
         * Sets the value of VpnGatewayId
         * @param vpnGatewayId `AWS::EC2::VPNGatewayRoutePropagation.VpnGatewayId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder vpnGatewayId(java.lang.String vpnGatewayId) {
            this.vpnGatewayId = vpnGatewayId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnVPNGatewayRoutePropagationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnVPNGatewayRoutePropagationProps build() {
            return new Jsii$Proxy(routeTableIds, vpnGatewayId);
        }

    }

    /**
     * An implementation for {@link CfnVPNGatewayRoutePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnVPNGatewayRoutePropagationProps {
        private final java.util.List<java.lang.String> routeTableIds;
        private final java.lang.String vpnGatewayId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.routeTableIds = this.jsiiGet("routeTableIds", java.util.List.class);
            this.vpnGatewayId = this.jsiiGet("vpnGatewayId", java.lang.String.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.util.List<java.lang.String> routeTableIds, java.lang.String vpnGatewayId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.routeTableIds = java.util.Objects.requireNonNull(routeTableIds, "routeTableIds is required");
            this.vpnGatewayId = java.util.Objects.requireNonNull(vpnGatewayId, "vpnGatewayId is required");
        }

        @Override
        public java.util.List<java.lang.String> getRouteTableIds() {
            return this.routeTableIds;
        }

        @Override
        public java.lang.String getVpnGatewayId() {
            return this.vpnGatewayId;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("routeTableIds", om.valueToTree(this.getRouteTableIds()));
            obj.set("vpnGatewayId", om.valueToTree(this.getVpnGatewayId()));
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnVPNGatewayRoutePropagationProps.Jsii$Proxy that = (CfnVPNGatewayRoutePropagationProps.Jsii$Proxy) o;

            if (!routeTableIds.equals(that.routeTableIds)) return false;
            return this.vpnGatewayId.equals(that.vpnGatewayId);
        }

        @Override
        public int hashCode() {
            int result = this.routeTableIds.hashCode();
            result = 31 * result + (this.vpnGatewayId.hashCode());
            return result;
        }

    }
}

==> ec2-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnVPNGatewayRoutePropagationProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::VPNGatewayRoutePropagation`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:56:19.018Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnVPNGatewayRoutePropagationProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::EC2::VPNGatewayRoutePropagation.RouteTableIds`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html#cfn-ec2-vpngatewayrouteprop-routetableids
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<java.lang.String> getRouteTableIds();

    /**
     * `AWS::EC2::VPNGatewayRoutePropagation.VpnGatewayId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html#cfn-ec2-vpngatewayrouteprop-vpngatewayid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getVpnGatewayId();

    /**
     * @return a {@link Builder} of {@link CfnVPNGatewayRoutePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnVPNGatewayRoutePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.util.List<java.lang.String> routeTableIds;
        private java.lang.String vpnGatewayId;

        /**
         * Sets the value of RouteTableIds
         * @param routeTableIds `AWS::EC2::VPNGatewayRoutePropagation.RouteTableIds`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder routeTableIds(java.util.List<java.lang.String> routeTableIds) {
            this.routeTableIds = routeTableIds;
            return this;
        }

        /**
         * Sets the value of VpnGatewayId
         * @param vpnGatewayId `AWS::EC2::VPNGatewayRoutePropagation.VpnGatewayId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder vpnGatewayId(java.lang.String vpnGatewayId) {
            this.vpnGatewayId = vpnGatewayId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnVPNGatewayRoutePropagationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnVPNGatewayRoutePropagationProps build() {
            return new Jsii$Proxy(routeTableIds, vpnGatewayId);
        }
    }

    /**
     * An implementation for {@link CfnVPNGatewayRoutePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnVPNGatewayRoutePropagationProps {
        private final java.util.List<java.lang.String> routeTableIds;
        private final java.lang.String vpnGatewayId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.routeTableIds = this.jsiiGet("routeTableIds", java.util.List.class);
            this.vpnGatewayId = this.jsiiGet("vpnGatewayId", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.util.List<java.lang.String> routeTableIds, java.lang.String vpnGatewayId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.routeTableIds = java.util.Objects.requireNonNull(routeTableIds, "routeTableIds is required");
            this.vpnGatewayId = java.util.Objects.requireNonNull(vpnGatewayId, "vpnGatewayId is required");
        }

        @Override
        public java.util.List<java.lang.String> getRouteTableIds() {
            return this.routeTableIds;
        }

        @Override
        public java.lang.String getVpnGatewayId() {
            return this.vpnGatewayId;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("routeTableIds", om.valueToTree(this.getRouteTableIds()));
            obj.set("vpnGatewayId", om.valueToTree(this.getVpnGatewayId()));
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnVPNGatewayRoutePropagationProps.Jsii$Proxy that = (CfnVPNGatewayRoutePropagationProps.Jsii$Proxy) o;

            if (!routeTableIds.equals(that.routeTableIds)) return false;
            return this.vpnGatewayId.equals(that.vpnGatewayId);
        }

        @Override
        public int hashCode() {
            int result = this.routeTableIds.hashCode();
            result = 31 * result + (this.vpnGatewayId.hashCode());
            return result;
        }
    }
}
